@@ -297,6 +297,13 @@ class StringInstanceTest < Test::Unit::TestCase
     end
   end
 
+  def test_append_as_bytes
+    if_ruby("3.4"...) do
+      assert_send_type  '(String) -> String',
+                        'hello', :append_as_bytes, "world"
+    end
+  end
+
   def test_ascii_only?
     assert_send_type  '() -> bool',
                       'hello', :ascii_only?
@@ -1259,11 +1266,15 @@ class StringInstanceTest < Test::Unit::TestCase
                       'hello', :scan, /l/
     assert_send_type  '(Regexp) -> Array[Array[String]]',
                       'hello', :scan, /(l)/
+    assert_send_type  '(Regexp) -> Array[Array[nil]]',
+                      'hello', :scan, /(x)?/
 
     assert_send_type  '(Regexp) { (String) -> void } -> String',
                       'hello', :scan, /l/ do end
     assert_send_type  '(Regexp) { (Array[String]) -> void } -> String',
                       'hello', :scan, /(l)/ do end
+    assert_send_type  '(Regexp) { (Array[nil]) -> void } -> String',
+                      'hello', :scan, /(x)?/ do end
 
     with_string 'l' do |pattern|
       assert_send_type  '(string) -> Array[String]',
@@ -1691,8 +1702,6 @@ class StringInstanceTest < Test::Unit::TestCase
       assert_send_type  '(string) { (Integer | Float | String | nil) -> void } -> nil',
                         packed, :unpack, template do end
 
-      next if RUBY_VERSION < '3.1'
-
       with_int 0 do |offset|
         assert_send_type  '(string, offset: int) -> Array[Integer | Float | String | nil]',
                           packed, :unpack, template, offset: offset
@@ -1710,8 +1719,6 @@ class StringInstanceTest < Test::Unit::TestCase
         assert_send_type  "(string) -> #{type}",
                           packed, :unpack1, template_string
 
-        next if RUBY_VERSION < '3.1'
-
         with_int 0 do |offset|
           assert_send_type  "(string, offset: int) -> #{type}",
                             packed, :unpack1, template_string, offset: offset
